==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/events/MapAuthEventEntityFields.java <==
package org.keycloak.models.map.events;
public enum MapAuthEventEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.events.MapAuthEventEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setId((String) value);
        }
    },
    CLIENT_ID {
        public static final String FIELD_NAME = "ClientId";
        public static final String FIELD_NAME_DASHED = "client-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (String) e.getClientId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setClientId((String) value);
        }
    },
    DETAILS {
        public static final String FIELD_NAME = "Details";
        public static final String FIELD_NAME_DASHED = "details";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (java.util.Map<String,String>) e.getDetails();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setDetails((java.util.Map<String,String>) value);
        }
    },
    ERROR {
        public static final String FIELD_NAME = "Error";
        public static final String FIELD_NAME_DASHED = "error";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setError((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (String) e.getError();
        }
    },
    EXPIRATION {
        public static final String FIELD_NAME = "Expiration";
        public static final String FIELD_NAME_DASHED = "expiration";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (Long) e.getExpiration();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setExpiration((Long) value);
        }
    },
    IP_ADDRESS {
        public static final String FIELD_NAME = "IpAddress";
        public static final String FIELD_NAME_DASHED = "ip-address";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setIpAddress((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (String) e.getIpAddress();
        }
    },
    REALM_ID {
        public static final String FIELD_NAME = "RealmId";
        public static final String FIELD_NAME_DASHED = "realm-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setRealmId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (String) e.getRealmId();
        }
    },
    SESSION_ID {
        public static final String FIELD_NAME = "SessionId";
        public static final String FIELD_NAME_DASHED = "session-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (String) e.getSessionId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setSessionId((String) value);
        }
    },
    TIMESTAMP {
        public static final String FIELD_NAME = "Timestamp";
        public static final String FIELD_NAME_DASHED = "timestamp";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (Long) e.getTimestamp();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setTimestamp((Long) value);
        }
    },
    TYPE {
        public static final String FIELD_NAME = "Type";
        public static final String FIELD_NAME_DASHED = "type";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return org.keycloak.events.EventType.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public org.keycloak.events.EventType get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (org.keycloak.events.EventType) e.getType();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setType((org.keycloak.events.EventType) value);
        }
    },
    USER_ID {
        public static final String FIELD_NAME = "UserId";
        public static final String FIELD_NAME_DASHED = "user-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (String) e.getUserId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setUserId((String) value);
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/events/MapAuthEventEntityFields.java <==
package org.keycloak.models.map.events;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapAuthEventEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.events.MapAuthEventEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        public static final String FIELD_NAME_CAMEL_CASE = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (String) e.getId();
        }
    },
    CLIENT_ID {
        public static final String FIELD_NAME = "ClientId";
        public static final String FIELD_NAME_DASHED = "client-id";
        public static final String FIELD_NAME_CAMEL_CASE = "clientId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setClientId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (String) e.getClientId();
        }
    },
    DETAILS {
        public static final String FIELD_NAME = "Details";
        public static final String FIELD_NAME_DASHED = "details";
        public static final String FIELD_NAME_CAMEL_CASE = "details";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setDetails((java.util.Map<String,String>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (java.util.Map<String,String>) e.getDetails();
        }
    },
    ERROR {
        public static final String FIELD_NAME = "Error";
        public static final String FIELD_NAME_DASHED = "error";
        public static final String FIELD_NAME_CAMEL_CASE = "error";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (String) e.getError();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setError((String) value);
        }
    },
    EXPIRATION {
        public static final String FIELD_NAME = "Expiration";
        public static final String FIELD_NAME_DASHED = "expiration";
        public static final String FIELD_NAME_CAMEL_CASE = "expiration";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setExpiration((Long) value);
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (Long) e.getExpiration();
        }
    },
    IP_ADDRESS {
        public static final String FIELD_NAME = "IpAddress";
        public static final String FIELD_NAME_DASHED = "ip-address";
        public static final String FIELD_NAME_CAMEL_CASE = "ipAddress";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setIpAddress((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (String) e.getIpAddress();
        }
    },
    REALM_ID {
        public static final String FIELD_NAME = "RealmId";
        public static final String FIELD_NAME_DASHED = "realm-id";
        public static final String FIELD_NAME_CAMEL_CASE = "realmId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (String) e.getRealmId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setRealmId((String) value);
        }
    },
    SESSION_ID {
        public static final String FIELD_NAME = "SessionId";
        public static final String FIELD_NAME_DASHED = "session-id";
        public static final String FIELD_NAME_CAMEL_CASE = "sessionId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (String) e.getSessionId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setSessionId((String) value);
        }
    },
    TIMESTAMP {
        public static final String FIELD_NAME = "Timestamp";
        public static final String FIELD_NAME_DASHED = "timestamp";
        public static final String FIELD_NAME_CAMEL_CASE = "timestamp";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setTimestamp((Long) value);
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (Long) e.getTimestamp();
        }
    },
    TYPE {
        public static final String FIELD_NAME = "Type";
        public static final String FIELD_NAME_DASHED = "type";
        public static final String FIELD_NAME_CAMEL_CASE = "type";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return org.keycloak.events.EventType.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setType((org.keycloak.events.EventType) value);
        }
        @SuppressWarnings("unchecked") @Override public org.keycloak.events.EventType get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (org.keycloak.events.EventType) e.getType();
        }
    },
    USER_ID {
        public static final String FIELD_NAME = "UserId";
        public static final String FIELD_NAME_DASHED = "user-id";
        public static final String FIELD_NAME_CAMEL_CASE = "userId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAuthEventEntity e) {
            return (String) e.getUserId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAuthEventEntity e, T value) {
            e.setUserId((String) value);
        }
    },
}
